% =================================================================================
% plot_contour          plots T and S contours (time series
%                       of profiles) for an Argo profile file.
%                       Use some parameters read by the
%                       function argo_file_read.
%                               
% AUTHOR:                Emmanuelle Autret
%
% HISTORIC:              23/10/2003 - EA - version 1.00 - 
%                        with matlab version 6.13
%
% REQUIRES:              netcdf matlab toolbox
%
% EXAMPLE:               file_name='6900162_500621518.nc';
%                        plot_contour
%
% SEE ALSO:              plot_latest_TS_profile.m, plot_contour.      
% 
% ================================================================================

[latitude,longitude,juld,pressure,temperature,salinity,platform_number,cycle_number,data_type,format_version,project_name,pi_name,direction,data_centre,data_state_indicator,data_mode,dc_reference,inst_reference,wmo_inst_type]=argo_file_read(file_name);


%PLOT T


figure
[nx,ny]=size(pressure);
pcolor(ones(ny,1)*cycle_number',-pressure',temperature');
hold on
shading interp;
contour(ones(ny,1)*cycle_number',-pressure',temperature',5,'k');
xlabel('cycle number');
ylabel('pressure (dcb)');
set(gca,'YLim',[min(min(-pressure))-1 0])
title(['Temperature (deg. C) for platform ' deblank(platform_number(1,:))])
hc=colorbar;
unitc=get(hc,'Units');
set(hc,'Units','pixels');
pos_hc=get(hc,'Position');
pos_hc_new=[pos_hc(1)*1.07 pos_hc(2) 20 pos_hc(4)];
set(hc,'Position',pos_hc_new);
set(hc,'Units',unitc);


set(gcf,'color',[1 1 1])



%PLOT S


figure
[nx,ny]=size(pressure);
pcolor(ones(ny,1)*cycle_number',-pressure',salinity');
hold on
shading interp;
contour(ones(ny,1)*cycle_number',-pressure',salinity',5,'k');
xlabel('cycle number');
ylabel('pressure (dcb)');
set(gca,'YLim',[min(min(-pressure))-1 0])
title(['Salinity (psu) for platform ' deblank(platform_number(1,:))])
hc=colorbar;
unitc=get(hc,'Units');
set(hc,'Units','pixels');
pos_hc=get(hc,'Position');
pos_hc_new=[pos_hc(1)*1.07 pos_hc(2) 20 pos_hc(4)];
set(hc,'Position',pos_hc_new);
set(hc,'Units',unitc);


set(gcf,'color',[1 1 1])
