% =================================================================================
%
% plot_latest_TS_profile    plots the latest T and S profiles
%                           contained in an Argo profile file.
%                           Use some parameters read by the
%                           function argo_file_read.
%                           
%
% AUTHOR:                Emmanuelle Autret
%
% HISTORIC:              23/10/2003 - EA - version 1.00 - 
%                        with matlab version 6.13
%
% REQUIRES:              netcdf matlab toolbox
%
% EXAMPLE:               file_name='6900162_500621518.nc';
%                        plot_latest_TS_profile                
%
% SEE ALSO:              argo_file_read.m, plot_contour.m.      
% 
% ================================================================================

[latitude,longitude,juld,pressure,temperature,salinity,platform_number,cycle_number,data_type,format_version,project_name,pi_name,direction,data_centre,data_state_indicator,data_mode,dc_reference,inst_reference,wmo_inst_type]=argo_file_read(file_name);

%PLOT


figure
subplot(1,2,1)
if ~isempty(temperature)
  plot(squeeze(temperature(end,:)),-squeeze(pressure(end,:)),'b')
  xlabel('temperature (deg.C)','Fontsize',8)
  ylabel('pressure (dcb)','Fontsize',8)
  grid on
  
end
subplot(1,2,2)
if ~isempty(salinity)
  plot(squeeze(salinity(end,:)),-squeeze(pressure(end,:)),'g')
  xlabel('salinity (psu)','Fontsize',8)
  ylabel('pressure (dcb)','Fontsize',8)
  grid on
end

set(gcf,'color',[1 1 1])

if (latitude(end)>=0)
  lat_str=[num2str(abs(latitude(end)),'%2.1f') 'N'];
else
  lat_str=[num2str(abs(latitude(end)),'%2.1f') 'S'];
end

if (longitude(end)>=0)
  lon_str=[num2str(abs(longitude(end)),'%2.1f') 'W'];
else 
  lon_str=[num2str(abs(longitude(end)),'%2.1f') 'E'];
end


suptitle(['Latest T and S profiles for platform ' ...
	  deblank(platform_number(end,:)) ' - cycle ' num2str(cycle_number(end)) ...
	  ' - ' datestr(juld(end),24) ...
	  ' - ' lat_str ', ' lon_str])
